Crate tray_wrapper

Crate tray_wrapper 

The tray wrapper library is intended to make it simple to provide a GUI tray icon for a given running server process. This uses the excellent tray-icon library for the UI and re-exports some of its types.

This is to make it convient to start and monitor a process on Mac (other operating systems are supported on a best effort basis). MacOS makes it challenging to manage a server process WITHOUT a tray icon.

The tray icon provides a submenu to view the supplied server status and the ability to exit.

Enums

ContinueRunning
CreateTrayWrapperError

Functions

create_tray_wrapper

Type Aliases

ServerGenerator
ServerGeneratorResult