pub struct TrayWrapper { /* private fields */ }Expand description
This is the main entry point / handle for the wrapper
Implementations
Sourceimpl TrayWrapper
impl TrayWrapper
Sourcepub fn new(
icon_data: &[u8],
event_loop_proxy: EventLoopProxy<UserEvent>,
server_gen: ServerGenerator,
) -> Result<Self, TrayWrapperError>
pub fn new( icon_data: &[u8], event_loop_proxy: EventLoopProxy<UserEvent>, server_gen: ServerGenerator, ) -> Result<Self, TrayWrapperError>
Construct the wrapper, its recommended you compile time load the icon which means you can ignore image parsing errors.