pub enum ContinueRunning {
Continue,
Exit,
ExitWithError(String),
}Expand description
The various options on if it should continue to execute the server again.
Variants
Continue
The server generator should be called again
Exit
There is no point in trying to execute again
ExitWithError(String)
There is no point in trying to execute again and we have a reason