pub type ServerGenerator = Arc<dyn Fn() -> ServerGeneratorResult + Send + Sync>;Expand description
This is the core of the library, in short you need to supply a function that when called returns async futures that can be polled.
Aliased Type
pub struct ServerGenerator { /* private fields */ }