pub type ServerGeneratorResult = Pin<Box<dyn Future<Output = ContinueRunning> + Send>>;Expand description
This is the return type for the async tasks, the future’s return type is to indicate to the wrapper if it should keep being executed.
Aliased Type
pub struct ServerGeneratorResult { /* private fields */ }